/**********************************************************************/
/*                                                                    */
/*  Sets subfolder properties.                                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/*  2001-02-05 : Added default sort attributes.                       */
/*  2000-02-15 : Added Status and warning messages; new interface.    */
/*  1999-08-25 : Cosmetic changes.                                    */
/*  1999-07-07 : Initial program release.                             */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* The latest version of this program can be found at                 */
/*               www.degeus.com/rexx                                  */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* This program is released under the terms of the GNU license, see   */
/*               www.gnu.org/copyleft/gpl.html                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* (c) 1999-2001 Marcus C. de Geus                                    */
/*               marcus@degeus.com                                    */
/*               www.degeus.com                                       */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* Use it if you like it. Don't if you don't. No legalese.            */
/*                                                                    */
/**********************************************************************/

signal on Halt  /* handle Halt condition */

if (\LoadRexxUtils()) then  /* if we cannot use or load the Rexx utility functions */
do
 call Halt  /* quit */
end

parse upper arg Params  /* get the parameters */

ParamString = ''  /* start with nothing */

FolderView = ''  /* start with nothing */
ContentsView = ''  /* start with nothing */
SortView = ''  /* start with nothing */

AlwaysSort = 'NO'  /* default to NO */
MenuBar = 'NO'  /* default to NO */
WorkArea = 'NO'  /* default to NO */

if (Params = '') then  /* if we have no parameters */
do
 call Usage  /* report */
 call Halt  /* and quit */
end

do while (Params >< '')  /* as long as we have parameters left */

 parse var Params Parameter Params  /* get the next one */

 select  /* do one of the following */

  when (Parameter = 'ALWAYSSORT') then  /* if we have this */
  do
   AlwaysSort = 'YES'  /* do this */
  end

  when (Parameter = 'MENUBAR') then  /* if we have this */
  do
   MenuBar = 'YES'  /* do this */
  end

  when (Parameter = 'WORKAREA') then  /* if we have this */
  do
   WorkArea = 'YES'  /* do this */
  end

  when (Parameter = 'ICON') then  /* if we have this */
  do
   FolderView = Parameter  /* do this */
  end

  when (Parameter = 'TREE') then  /* if we have this */
  do
   FolderView = Parameter  /* do this */
  end

  when (Parameter = 'DETAILS') then  /* if we have this */
  do
   FolderView = Parameter  /* do this */
  end

  when (Parameter = 'NORMAL') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'MINI') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'FLOWED') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'NONFLOWED') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'NONGRID') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'NORMAL') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'INVISIBLE') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'LINES') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'NOLINES') then  /* if we have this */
  do
   ContentsView = ContentsView||','||Parameter  /* do this */
  end

  when (Parameter = 'NAME') then  /* if we have this */
  do
   SortView = -2  /* use this default sort parameter */
  end

  when (Parameter = 'TYPE') then  /* if we have this */
  do
   SortView = -1  /* use this default sort parameter */
  end

  when (Parameter = 'FIRSTITEM') then  /* if we have this */
  do
   SortView = 0  /* use this default sort parameter */
  end

  when (Parameter = 'REALNAME') then  /* if we have this */
  do
   SortView = 5  /* use this default sort parameter */
  end

  when (Parameter = 'SIZE') then  /* if we have this */
  do
   SortView = 6  /* use this default sort parameter */
  end

  when (Parameter = 'LASTWRITEDATE') then  /* if we have this */
  do
   SortView = 7  /* use this default sort parameter */
  end

  when (Parameter = 'LASTACCESSDATE') then  /* if we have this */
  do
   SortView = 9  /* use this default sort parameter */
  end

  when (Parameter = 'CREATIONDATE') then  /* if we have this */
  do
   SortView = 11  /* use this default sort parameter */
  end

  otherwise  /* if we have something else */
  do
   call Usage  /* report */
   call Halt  /* and quit */
  end

 end

end

if (FolderView >< '') then  /* if we have a default folder view parameter */
do
 ParamString = 'DEFAULTVIEW='||FolderView||';'  /* string to set the default folder view */
 if (ContentsView >< '') then  /* if we have icon view parameters */
 do
  ParamString = ParamString||FolderView||'VIEW='||strip(ContentsView,'L',',')||';'  /* add them to the setup string */
 end
end

if (SortView >< '') then  /* if we have a default folder sort parameter */
do
 ParamString = ParamString||'DEFAULTSORT='||SortView||';'  /* add a string to set the default folder sort action */
end

ParamString = ParamString||'ALWAYSSORT='||AlwaysSort||';'  /* add this parameters to the setup string */
ParamString = ParamString||'MENUBAR='||MenuBar||';'  /* add this parameters to the setup string */
ParamString = ParamString||'WORKAREA='||WorkArea||';'  /* add this parameters to the setup string */

CurDir = directory()  /* get the name of the current folder */

Target = strip(directory(),'T','\')||'\*.*'  /* the folder objects to look for */

call sysfiletree Target,'SubDirs.','DOS'  /* look for subfolders */

CurDirNo = SubDirs.0 + 1  /* we're going to add the current folder, so up the counter by one */
SubDirs.CurDirNo = CurDir  /* insert the current folder name at the end of the bunch */

SayString = ParamString  /* copy the parameter string */
say CurDir||' and any subfolders will receive the following attributes:'  /* report */
do while (SayString >< '')  /* for each bit followed by a semicolon */
 parse var SayString String ';' SayString  /* get the bit */
 say '  '||String  /* and report it */
end
call charout ,'Continue? (Y/N) Y'||d2c(8)  /* put out a query text */
Reply = translate(sysgetkey('ECHO'))  /* get a character from STDIN and make it upper case */
if (pos(Reply,d2c(13)||'Y+') = 0) then  /* if we don't get the O.K. */
do
 call Halt  /* quit */
end

say ''  /* add an empty line */
do Index = 1 to CurDirNo  /* take each of the (sub)folders found */
 if (syssetobjectdata(SubDirs.Index,ParamString)) then  /* if we can set the attributes */
 do
  say 'Setting attributes of '||SubDirs.Index  /* report */
 end
 else  /* if we cannot set the attributes */
 do
  say 'Cannot set the attributes for '||SubDirs.Index  /* report */
 end
end

call Halt  /* quit */

/**********************************************************************/
Usage: procedure  /* handles error condition */
/**********************************************************************/

parse source . . ProgName  /* get the full program name */
ProgName = filespec('N',ProgName)  /* extract the short program name */
parse var ProgName NameBit '.' .  /* extract the name without the extension */

say 'This program sets the view attributes of the current folder and subfolders'  /* give some info */
say 'Usage  : '||NameBit||' [option 1] [option 2] ... [option n]'  /* some more info */
say 'Options: '  /* some more info */
say '  details [normal|mini]]'  /* some more info */
say '      details view'  /* some more info */
say '      normal or mini icons'  /* some more info */
say '  icon [normal|mini|invisible] [flowed|nonflowed|nongrid]'  /* some more info */
say '      icon view'  /* some more info */
say '      normal, mini, or invisible icons'  /* some more info */
say '      flowed, non-flowed, or non-grid layout'  /* some more info */
say '  tree [normal|mini|invisible] [lines|nolines]'  /* some more info */
say '      tree view'  /* some more info */
say '      normal, mini, or invisible icons'  /* some more info */
say '      lines or no lines between items'  /* some more info */
say '  name|type|firstitem|realname|size|lastwritedate|lastaccessdate|creationdate'  /* some more info */
say '      default sort action is by name, type, first item on poup menu, real name,'  /* some more info */
say '      size, last write date, last access date, or creation date'  /* some more info */
say '  alwayssort'  /* some more info */
say '      always sort folder contents'  /* some more info */
say '  menubar'  /* some more info */
say '      show folder menu bar'  /* some more info */
say '  workarea'  /* some more info */
say '      make folder a work area'  /* some more info */

return  /* end of Usage */

/**********************************************************************/
LoadRexxUtils: procedure  /* loads REXX utility functions if necessary */
/**********************************************************************/

Success = 1  /* all is well to start with */

if (rxfuncquery('SysLoadFuncs') >< 0) then  /* if we have to load the REXX utility functions */
do
 if (rxfuncadd('SysLoadFuncs','RexxUtil','SysLoadFuncs') = 0) then  /* if we can register the general loading function */
 do
  call sysloadfuncs  /* call the general loading function */
  say 'Rexx utility functions loaded'  /* report */
 end
 else  /* if we cannot register the general loading function */
 do
  say  'Cannot load Rexx utility functions'  /* report */
  Success = 0  /* no success */
 end
end

return Success  /* end of LoadRexxUtils */

/**********************************************************************/
Halt:  /* handles Halt condition */
/**********************************************************************/

exit  /* that's all, folks!*/
